<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.ui" line="+14"/>
        <source>About Transmission</source>
        <translation>O&#xa0;programie</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Copyright © The Transmission Project</source>
        <translation>Copyright © Projekt Transmission</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>A fast and easy BitTorrent client</source>
        <translation>Szybki i&#xa0;łatwy w&#xa0;użyciu klient sieci BitTorrent</translation>
    </message>
    <message>
        <location filename="../AboutDialog.cc" line="+37"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Server</source>
        <translation>Serwer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>C&amp;redits</source>
        <translation>&amp;Zasługi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>&amp;License</source>
        <translation>&amp;Licencja</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Credits</source>
        <translation>Zasługi</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <location filename="../Application.cc" line="+332"/>
        <source>&lt;b&gt;Transmission is a file sharing program.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Transmission jest programem do udostępniania plików.&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.</source>
        <translation>Kiedy uruchamiany jest torrent, jego dane stają się dostępne dla innych. Wyłącznie użytkownik jest odpowiedzialny za każdą udostępnianą treść.</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>I &amp;Agree</source>
        <translation>&amp;Zgadzam się</translation>
    </message>
    <message numerus="yes">
        <location line="+110"/>
        <source>Torrent(s) Completed</source>
        <translation>
            <numerusform>Ukończono torrent</numerusform>
            <numerusform>Ukończono torrenty</numerusform>
            <numerusform>Ukończono torrenty</numerusform>
        </translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Torrent Added</source>
        <translation>Dodano torrent</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../DetailsDialog.cc" line="+432"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Mixed</source>
        <translation>Mieszane</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+267"/>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
    <message>
        <location line="-210"/>
        <source>Finished</source>
        <translation>Ukończono</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>%1 (+%2 discarded after failed checksum)</source>
        <translation>%1 (+%2 odrzucone po nieudanej sumie kontrolnej)</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Active now</source>
        <translation>Obecnie aktywne</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 ago</source>
        <translation>%1 temu</translation>
    </message>
    <message numerus="yes">
        <location line="+63"/>
        <source>%1 (%Ln pieces @ %2)</source>
        <translation>
            <numerusform>%1 (%Ln część o&#xa0;%2)</numerusform>
            <numerusform>%1 (%Ln części po %2)</numerusform>
            <numerusform>%1 (%Ln części po %2)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%1 (%Ln pieces)</source>
        <translation>
            <numerusform>%1 (%Ln część)</numerusform>
            <numerusform>%1 (%Ln części)</numerusform>
            <numerusform>%1 (%Ln części)</numerusform>
        </translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Private to this tracker -- DHT and PEX disabled</source>
        <translation>Prywatne dla tego serwera śledzącego — DHT i&#xa0;PEX są wyłączone</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Public torrent</source>
        <translation>Publiczny torrent</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Created by %1</source>
        <translation>Utworzony przez: %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created on %1</source>
        <translation>Utworzony dnia %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Created by %1 on %2</source>
        <translation>Utworzony dnia %2 przez: %1</translation>
    </message>
    <message>
        <location line="+204"/>
        <location line="+47"/>
        <source>Encrypted connection</source>
        <translation>Zaszyfrowane połączenie</translation>
    </message>
    <message>
        <location line="-28"/>
        <source>Optimistic unchoke</source>
        <translation>Optymistyczne odblokowanie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading from this peer</source>
        <translation>Pobieranie od tego partnera</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would download from this peer if they would let us</source>
        <translation>Pobieranie od tego partnera zostanie rozpoczęte po otrzymaniu zgody</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Uploading to peer</source>
        <translation>Wysyłanie do partnera</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We would upload to this peer if they asked</source>
        <translation>Wysyłanie do tego partnera zostanie rozpoczęte po otrzymaniu zapytania</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer has unchoked us, but we&apos;re not interested</source>
        <translation>Partner odblokował tego klienta, ale nie jesteśmy zainteresowani</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>We unchoked this peer, but they&apos;re not interested</source>
        <translation>Odblokowano tego partnera, ale nie jest on zainteresowany</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer was discovered through DHT</source>
        <translation>Partner został wykryty przez DHT</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer was discovered through Peer Exchange (PEX)</source>
        <translation>Partner został wykryty przez PEX (wymianę partnerów)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is an incoming connection</source>
        <translation>Partner jest połączeniem przychodzącym</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Peer is connected over µTP</source>
        <translation>Partner jest połączony przez µTP</translation>
    </message>
    <message numerus="yes">
        <location line="+130"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform> minuta</numerusform>
            <numerusform> minuty</numerusform>
            <numerusform> minut</numerusform>
        </translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Add tracker announce URLs, one per line:</source>
        <translation>Dodanie adresów URL ogłoszenia serwera śledzącego, jeden na wiersz:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No new URLs found.</source>
        <translation>Nie odnaleziono nowych adresów URL.</translation>
    </message>
    <message>
        <location line="-843"/>
        <source>%1 (100%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data</extracomment>
        <translation>%1 (100%)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded and verified data, %2 is overall size of torrent data, %3 is percentage (%1/%2*100)</extracomment>
        <translation>%1 z&#xa0;%2 (%3%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%), %4 Unverified</source>
        <extracomment>Text following the &quot;Have:&quot; label in torrent properties dialog; %1 is amount of downloaded data (both verified and unverified), %2 is overall size of torrent data, %3 is percentage (%1/%2*100), %4 is amount of downloaded but not yet verified data</extracomment>
        <translation>%1 z&#xa0;%2 (%3%), %4 niesprawdzone</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>%1 (Ratio: %2)</source>
        <translation>%1 (udział: %2)</translation>
    </message>
    <message>
        <location line="+273"/>
        <location line="+55"/>
        <source>N/A</source>
        <translation>Nie dotyczy</translation>
    </message>
    <message>
        <location line="+390"/>
        <source>Add URL(s)</source>
        <translation>Dodaj adresy URL</translation>
    </message>
    <message>
        <location line="+114"/>
        <source>High</source>
        <translation>Wysoki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Zwykły</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Niski</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+4"/>
        <source>Use Global Settings</source>
        <translation>Globalne ustawienia</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Seed regardless of ratio</source>
        <translation>Wysyłanie niezależnie od udziału</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding at ratio:</source>
        <translation>Zatrzymanie wysyłania po osiągnięciu udziału:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Seed regardless of activity</source>
        <translation>Wysyłanie niezależnie od aktywności</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stop seeding if idle for:</source>
        <translation>Zatrzymanie wysyłania po braku aktywności przez:</translation>
    </message>
    <message>
        <location line="+75"/>
        <source>Up</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Down</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status</source>
        <translation>Stan</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location filename="../DetailsDialog.ui" line="+14"/>
        <source>Torrent Properties</source>
        <translation>Właściwości torrenta</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Information</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Activity</source>
        <translation>Aktywność</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Have:</source>
        <translation>Posiadane:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Availability:</source>
        <translation>Dostępność:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Uploaded:</source>
        <translation>Wysłano:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Downloaded:</source>
        <translation>Pobrano:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>State:</source>
        <translation>Stan:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Running time:</source>
        <translation>Czas działania:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Remaining time:</source>
        <translation>Pozostały czas:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Last activity:</source>
        <translation>Ostatnia aktywność:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Details</source>
        <translation>Pozostałe informacje</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Location:</source>
        <translation>Położenie:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Edit Trackers</source>
        <translation>Modyfikuj serwery śledzące</translation>
    </message>
    <message>
        <location line="-190"/>
        <source>Hash:</source>
        <translation>Suma kontrolna:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Privacy:</source>
        <translation>Prywatność:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Origin:</source>
        <translation>Powstanie:</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Added:</source>
        <translation>Dodano:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Peers</source>
        <translation>Partnerzy</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tracker</source>
        <translation>Serwer śledzący</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add Tracker</source>
        <translation>Dodaj serwer śledzący</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Remove Trackers</source>
        <translation>Usuń serwery śledzące</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Show &amp;more details</source>
        <translation>&amp;Więcej informacji</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show &amp;backup trackers</source>
        <translation>&amp;Zapasowe serwery śledzące</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Honor global &amp;limits</source>
        <translation>&amp;Globalne ograniczenia</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Limit &amp;download speed:</source>
        <translation>&amp;Ograniczenie prędkości pobierania:</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>Limit &amp;upload speed:</source>
        <translation>Ograniczenie prędkości &amp;wysyłania:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Torrent &amp;priority:</source>
        <translation>&amp;Priorytet torrenta:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Seeding Limits</source>
        <translation>Ograniczenia wysyłania</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Ratio:</source>
        <translation>&amp;Udział:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Idle:</source>
        <translation>&amp;Brak aktywności:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Peer Connections</source>
        <translation>Połączenia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Maximum peers:</source>
        <translation>&amp;Maksymalna liczba partnerów:</translation>
    </message>
</context>
<context>
    <name>FileTreeItem</name>
    <message>
        <location filename="../FileTreeItem.cc" line="+297"/>
        <location filename="../FileTreeView.cc" line="+108"/>
        <location line="+254"/>
        <source>Low</source>
        <translation>Niski</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-254"/>
        <location line="+252"/>
        <source>High</source>
        <translation>Wysoki</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <location line="+253"/>
        <source>Normal</source>
        <translation>Zwykły</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../FileTreeView.cc" line="-252"/>
        <source>Mixed</source>
        <translation>Mieszane</translation>
    </message>
</context>
<context>
    <name>FileTreeModel</name>
    <message>
        <location filename="../FileTreeModel.cc" line="+195"/>
        <source>File</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Download</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Priority</source>
        <translation>Priorytet</translation>
    </message>
</context>
<context>
    <name>FileTreeView</name>
    <message>
        <location filename="../FileTreeView.cc" line="+244"/>
        <source>Check Selected</source>
        <translation>Zaznacz wybrane</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uncheck Selected</source>
        <translation>Odznacz wybrane</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Only Check Selected</source>
        <translation>Zaznacz tylko wybrane</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Priority</source>
        <translation>Priorytet</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rename…</source>
        <translation>Zmień nazwę…</translation>
    </message>
</context>
<context>
    <name>FilterBar</name>
    <message>
        <location filename="../FilterBar.cc" line="+48"/>
        <location line="+145"/>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <location line="-136"/>
        <source>Active</source>
        <translation>Aktywne</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Seeding</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Finished</source>
        <translation>Ukończono</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Verifying</source>
        <translation>Sprawdzanie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location line="+140"/>
        <source>Show:</source>
        <translation>Wyświetlanie:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Search…</source>
        <translation>Wyszukaj…</translation>
    </message>
</context>
<context>
    <name>Formatter</name>
    <message>
        <location filename="../Formatter.cc" line="+24"/>
        <source>B/s</source>
        <translation>B/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>kB/s</source>
        <translation>kB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB/s</source>
        <translation>MB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB/s</source>
        <translation>GB/s</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB/s</source>
        <translation>TB/s</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GB</source>
        <translation>GB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TB</source>
        <translation>TB</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location line="+37"/>
        <location line="+25"/>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
    <message>
        <location line="-20"/>
        <location line="+10"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location filename="../Formatter.h" line="+64"/>
        <location line="+7"/>
        <source>%1 %2</source>
        <translation>%1 %2</translation>
    </message>
    <message numerus="yes">
        <location filename="../Formatter.cc" line="+41"/>
        <source>%Ln day(s)</source>
        <translation>
            <numerusform>%Ln dzień</numerusform>
            <numerusform>%Ln dni</numerusform>
            <numerusform>%Ln dni</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-5"/>
        <source>%Ln hour(s)</source>
        <translation>
            <numerusform>%Ln godzina</numerusform>
            <numerusform>%Ln godziny</numerusform>
            <numerusform>%Ln godzin</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuta</numerusform>
            <numerusform>%Ln minuty</numerusform>
            <numerusform>%Ln minut</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-7"/>
        <source>%Ln second(s)</source>
        <translation>
            <numerusform>%Ln sekunda</numerusform>
            <numerusform>%Ln sekundy</numerusform>
            <numerusform>%Ln sekund</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FreeSpaceLabel</name>
    <message>
        <location filename="../FreeSpaceLabel.cc" line="+52"/>
        <source>&lt;i&gt;Calculating Free Space…&lt;/i&gt;</source>
        <translation>&lt;i&gt;Obliczanie wolnego miejsca…&lt;/i&gt;</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>%1 free</source>
        <translation>Wolne: %1</translation>
    </message>
</context>
<context>
    <name>LicenseDialog</name>
    <message>
        <location filename="../LicenseDialog.ui" line="+14"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../MainWindow.ui" line="+14"/>
        <source>Transmission</source>
        <translation>Transmission</translation>
    </message>
    <message>
        <location line="+181"/>
        <source>&amp;Torrent</source>
        <translation>&amp;Torrent</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Help</source>
        <translation>Pomo&amp;c</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Create a new torrent</source>
        <translation>Tworzy nowy torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Properties</source>
        <translation>&amp;Właściwości</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Show torrent properties</source>
        <translation>Wyświetla właściwości torrenta</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Open the torrent&apos;s folder</source>
        <translation>Otwiera katalog torrenta</translation>
    </message>
    <message>
        <location line="-161"/>
        <source>Queue</source>
        <translation>Kolejka</translation>
    </message>
    <message>
        <location line="-132"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <location line="+83"/>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <location line="+171"/>
        <source>&amp;Open…</source>
        <translation>&amp;Otwórz…</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Open a torrent</source>
        <translation>Otwiera torrent</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;New…</source>
        <translation>&amp;Nowy…</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Open Fold&amp;er</source>
        <translation>Otwórz &amp;katalog</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Start</source>
        <translation>&amp;Rozpocznij</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start torrent</source>
        <translation>Rozpoczyna torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Ask Tracker for &amp;More Peers</source>
        <translation>Wyślij zapyta&amp;nie o&#xa0;więcej partnerów</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ask tracker for more peers</source>
        <translation>Wysyła zapytanie o&#xa0;więcej partnerów</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause</source>
        <translation>W&amp;strzymaj</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Pause torrent</source>
        <translation>Wstrzymuje torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Verify Local Data</source>
        <translation>Spra&amp;wdź pobrane dane</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Verify local data</source>
        <translation>Sprawdza pobrane dane</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Remove</source>
        <translation>&amp;Usuń</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent</source>
        <translation>Usuwa torrent</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Delete Files and Remove</source>
        <translation>&amp;Usuń wraz z&#xa0;plikami</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Remove torrent and delete its files</source>
        <translation>Usuwa torrent wraz z&#xa0;jego plikami</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Start All</source>
        <translation>Rozpocznij w&amp;szystko</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Pause All</source>
        <translation>&amp;Wstrzymaj wszystko</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Quit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Select All</source>
        <translation>Zazn&amp;acz wszystko</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Deselect All</source>
        <translation>Odz&amp;nacz wszystko</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Preferences</source>
        <translation>&amp;Preferencje</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Compact View</source>
        <translation>&amp;Zwarty</translation>
    </message>
    <message>
        <location line="+3"/>
        <location line="+3"/>
        <source>Compact View</source>
        <translation>Widok zwarty</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>&amp;Toolbar</source>
        <translation>Pasek &amp;narzędziowy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Filterbar</source>
        <translation>&amp;Pasek filtrów</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statusbar</source>
        <translation>Pasek &amp;stanu</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Activity</source>
        <translation>Według &amp;aktywności</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by A&amp;ge</source>
        <translation>Według &amp;czasu dodania</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Time &amp;Left</source>
        <translation>Według po&amp;zostałego czasu</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Name</source>
        <translation>Według &amp;nazw</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Progress</source>
        <translation>Według p&amp;ostępu</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Rati&amp;o</source>
        <translation>Według &amp;udziału</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Si&amp;ze</source>
        <translation>Według &amp;rozmiaru</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by Stat&amp;e</source>
        <translation>Według &amp;stanu</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by T&amp;racker</source>
        <translation>Według s&amp;erwerów śledzących</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Message &amp;Log</source>
        <translation>&amp;Dziennik komunikatów</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Statistics</source>
        <translation>&amp;Statystyki</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Contents</source>
        <translation>&amp;Spis treści</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;About</source>
        <translation>&amp;O&#xa0;programie</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Re&amp;verse Sort Order</source>
        <translation>Odw&amp;rócona kolejność</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Name</source>
        <translation>&amp;Nazwa</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Files</source>
        <translation>&amp;Pliki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Tracker</source>
        <translation>&amp;Serwer śledzący</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Ratio</source>
        <translation>Udział całkowity</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Ratio</source>
        <translation>Udział w&#xa0;sesji</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Total Transfer</source>
        <translation>Przesłano całkowicie</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Session Transfer</source>
        <translation>Przesłano w&#xa0;sesji</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Main Window</source>
        <translation>&amp;Główne okno</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tray &amp;Icon</source>
        <translation>&amp;Ikona w&#xa0;obszarze powiadamiania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Change Session…</source>
        <translation>&amp;Zmień sesję…</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Set &amp;Location…</source>
        <translation>Ustaw p&amp;ołożenie…</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Open &amp;URL…</source>
        <translation>Otwórz adres &amp;URL…</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Choose Session</source>
        <extracomment>Start a local session or connect to a running session</extracomment>
        <translation>Wybierz sesję</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Copy Magnet Link to Clipboard</source>
        <translation>Skopiuj odnośnik &amp;magnet do schowka</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Donate</source>
        <translation>&amp;Wsparcie finansowe</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start &amp;Now</source>
        <translation>Rozpocz&amp;nij teraz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Bypass the queue and start now</source>
        <translation>Obchodzi kolejkę i&#xa0;rozpoczyna teraz</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Move to &amp;Top</source>
        <translation>Przesuń na gó&amp;rę</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Move &amp;Up</source>
        <translation>Przesuń &amp;wyżej</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move &amp;Down</source>
        <translation>Przesuń &amp;niżej</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move to &amp;Bottom</source>
        <translation>Przesuń na &amp;dół</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Sort by &amp;Queue</source>
        <translation>Według &amp;kolejki</translation>
    </message>
    <message>
        <location filename="../MainWindow.cc" line="+468"/>
        <source>Limit Download Speed</source>
        <translation>Ograniczenie prędkości pobierania</translation>
    </message>
    <message>
        <location line="-55"/>
        <source>Unlimited</source>
        <translation>Bez ograniczenia</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+752"/>
        <location line="+9"/>
        <source>Limited at %1</source>
        <translation>Ograniczenie do %1</translation>
    </message>
    <message>
        <location line="-706"/>
        <source>Limit Upload Speed</source>
        <translation>Ograniczenie prędkości wysyłania</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Stop Seeding at Ratio</source>
        <translation>Zatrzymanie wysyłania po osiągnięciu udziału</translation>
    </message>
    <message>
        <location line="-40"/>
        <source>Seed Forever</source>
        <translation>Wysyłanie bez końca</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+739"/>
        <source>Stop at Ratio (%1)</source>
        <translation>Zatrzymanie przy udziale (%1)</translation>
    </message>
    <message>
        <location line="-393"/>
        <source> - %1:%2</source>
        <extracomment>Second (optional) part of main window title &quot;Transmission - host:port&quot; (added when connected to remote session) notice that leading space (before the dash) is included here</extracomment>
        <translation> — %1:%2</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Idle</source>
        <translation>Bezczynny</translation>
    </message>
    <message>
        <location line="+30"/>
        <location line="+15"/>
        <source>Ratio: %1</source>
        <translation>Udział: %1</translation>
    </message>
    <message>
        <location line="-10"/>
        <location line="+5"/>
        <source>Down: %1, Up: %2</source>
        <translation>Pobrano: %1, wysłano: %2</translation>
    </message>
    <message>
        <location line="+424"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Pliki torrent (*.torrent);;Wszystkie pliki (*.*)</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show &amp;options dialog</source>
        <translation>O&amp;kno opcji</translation>
    </message>
    <message>
        <location line="-8"/>
        <source>Open Torrent</source>
        <translation>Otwórz torrent</translation>
    </message>
    <message>
        <location line="-1003"/>
        <source>Speed Limits</source>
        <translation>Ograniczenia</translation>
    </message>
    <message>
        <location line="+537"/>
        <source>Network Error</source>
        <translation>Błąd sieci</translation>
    </message>
    <message>
        <location line="+434"/>
        <source>Click to disable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Wyłącza tymczasowe ograniczenia prędkości
 (pobieranie %1, wysyłanie %2)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Click to enable Temporary Speed Limits
 (%1 down, %2 up)</source>
        <translation>Włącza tymczasowe ograniczenia prędkości
 (pobieranie %1, wysyłanie %2)</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Remove torrent?</source>
        <translation>Usunąć torrent?</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Delete this torrent&apos;s downloaded files?</source>
        <translation>Usunąć pobrane pliki torrenta?</translation>
    </message>
    <message numerus="yes">
        <location line="-4"/>
        <source>Remove %Ln torrent(s)?</source>
        <translation>
            <numerusform>Usunąć %Ln torrent?</numerusform>
            <numerusform>Usunąć %Ln torrenty?</numerusform>
            <numerusform>Usunąć %Ln torrentów?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-505"/>
        <source>Showing %L1 of %Ln torrent(s)</source>
        <translation>
            <numerusform>Wyświetlanie %L1 z&#xa0;%Ln torrenta</numerusform>
            <numerusform>Wyświetlanie %L1 z&#xa0;%Ln torrentów</numerusform>
            <numerusform>Wyświetlanie %L1 z&#xa0;%Ln torrentów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+510"/>
        <source>Delete these %Ln torrent(s)&apos; downloaded files?</source>
        <translation>
            <numerusform>Usunąć pobrane pliki %Ln torrenta?</numerusform>
            <numerusform>Usunąć pobrane pliki %Ln torrentów?</numerusform>
            <numerusform>Usunąć pobrane pliki %Ln torrentów?</numerusform>
        </translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Once removed, continuing the transfer will require the torrent file or magnet link.</source>
        <translation>Po usunięciu, wznowienie przesyłania będzie wymagało pliku torrent lub odnośnika magnet.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Once removed, continuing the transfers will require the torrent files or magnet links.</source>
        <translation>Po usunięciu, wznowienie przesyłania będzie wymagało plików torrent lub odnośników magnet.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent has not finished downloading.</source>
        <translation>Ten torrent nie ukończył pobierania.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>These torrents have not finished downloading.</source>
        <translation>Te torrenty nie ukończyły pobierania.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>This torrent is connected to peers.</source>
        <translation>Ten torrent jest połączony z&#xa0;partnerami.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>These torrents are connected to peers.</source>
        <translation>Te torrenty są połączone z&#xa0;partnerami.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>One of these torrents is connected to peers.</source>
        <translation>Jeden z&#xa0;tych torrentów jest połączony z&#xa0;partnerami.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents are connected to peers.</source>
        <translation>Niektóre z&#xa0;tych torrentów są połączone z&#xa0;partnerami.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>One of these torrents has not finished downloading.</source>
        <translation>Jeden z&#xa0;tych torrentów nie ukończył pobierania.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Some of these torrents have not finished downloading.</source>
        <translation>Niektóre z&#xa0;tych torrentów nie ukończyły pobierania.</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>%1 has not responded yet</source>
        <translation>%1 jeszcze nie odpowiedział</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>%1 is responding</source>
        <translation>%1 odpowiada</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 last responded %2 ago</source>
        <translation>%1 ostatnio odpowiedział %2 temu</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 is not responding</source>
        <translation>%1 nie odpowiada</translation>
    </message>
</context>
<context>
    <name>MakeDialog</name>
    <message>
        <location filename="../MakeDialog.ui" line="+17"/>
        <source>New Torrent</source>
        <translation>Nowy torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="+304"/>
        <source>&lt;i&gt;No source selected&lt;/i&gt;</source>
        <translation>&lt;i&gt;Nie wybrano źródła&lt;/i&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="+5"/>
        <source>%Ln File(s)</source>
        <translation>
            <numerusform>%Ln plik</numerusform>
            <numerusform>%Ln pliki</numerusform>
            <numerusform>%Ln plików</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+1"/>
        <source>%Ln Piece(s)</source>
        <translation>
            <numerusform>%Ln część</numerusform>
            <numerusform>%Ln części</numerusform>
            <numerusform>%Ln części</numerusform>
        </translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 in %2; %3 @ %4</source>
        <translation>%1 w&#xa0;%2, %3 o&#xa0;%4</translation>
    </message>
    <message>
        <location filename="../MakeDialog.ui" line="+9"/>
        <source>Files</source>
        <translation>Pliki</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Sa&amp;ve to:</source>
        <translation>&amp;Zapisanie do:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Source f&amp;older:</source>
        <translation>&amp;Katalog źródłowy:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Source &amp;file:</source>
        <translation>&amp;Plik źródłowy:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Piece s&amp;ize:</source>
        <translation>Roz&amp;miar części:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Trackers:</source>
        <translation>&amp;Serwery śledzące:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>To add a backup URL, add it on the line after the primary URL.
To add another primary URL, add it after a blank line.</source>
        <translation>Zapasowy adres URL należy dodać do wiersza za podstawowym adresem URL.
Kolejny podstawowy adres URL należy dodać po pustym wierszu.</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Co&amp;mment:</source>
        <translation>Ko&amp;mentarz:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Source:</source>
        <translation>Źró&amp;dło:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&amp;Private torrent</source>
        <translation>P&amp;rywatny torrent</translation>
    </message>
</context>
<context>
    <name>MakeProgressDialog</name>
    <message>
        <location filename="../MakeProgressDialog.ui" line="+14"/>
        <source>New Torrent</source>
        <translation>Nowy torrent</translation>
    </message>
    <message>
        <location filename="../MakeDialog.cc" line="-184"/>
        <source>Creating &quot;%1&quot;</source>
        <translation>Tworzenie „%1”</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Created &quot;%1&quot;!</source>
        <translation>Utworzono „%1”.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Couldn&apos;t create &quot;%1&quot;: %2 (%3)</source>
        <translation>Nie można utworzyć „%1”: %2 (%3)</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../OptionsDialog.cc" line="+52"/>
        <source>Open Torrent</source>
        <translation>Otwarcie torrenta</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Open Torrent from File</source>
        <translation>Otwarcie torrenta z&#xa0;pliku</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open Torrent from URL or Magnet Link</source>
        <translation>Otwarcie torrenta z&#xa0;adresu URL lub odnośnika magnet</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+17"/>
        <source>&amp;Source:</source>
        <translation>Ź&amp;ródło:</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Destination folder:</source>
        <translation>Katalog &amp;docelowy:</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="+49"/>
        <source>High</source>
        <translation>Wysoki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Normal</source>
        <translation>Zwykły</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low</source>
        <translation>Niski</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.ui" line="+35"/>
        <source>&amp;Priority:</source>
        <translation>&amp;Priorytet:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>S&amp;tart when added</source>
        <translation>&amp;Rozpoczęcie po dodaniu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Mo&amp;ve .torrent file to the trash</source>
        <translation>&amp;Przeniesienie pliku .torrent do kosza</translation>
    </message>
    <message>
        <location filename="../OptionsDialog.cc" line="-40"/>
        <source>Torrent Files (*.torrent);;All Files (*.*)</source>
        <translation>Pliki torrent (*.torrent);;Wszystkie pliki (*.*)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Select Destination</source>
        <translation>Wybór miejsca docelowego</translation>
    </message>
</context>
<context>
    <name>PathButton</name>
    <message>
        <location filename="../PathButton.cc" line="+23"/>
        <location line="+71"/>
        <source>(None)</source>
        <translation>(Brak)</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Select Folder</source>
        <translation>Wybór katalogu</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Select File</source>
        <translation>Wybór pliku</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <location filename="../PrefsDialog.ui" line="+1223"/>
        <source>Use &amp;authentication</source>
        <translation>Uwierzytelni&amp;anie</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Username:</source>
        <translation>Nazwa &amp;użytkownika:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>&amp;Hasło:</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>&amp;Open web client</source>
        <translation>&amp;Otwórz klienta WWW</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Addresses:</source>
        <translation>Adresy:</translation>
    </message>
    <message>
        <location line="-1234"/>
        <source>Speed Limits</source>
        <translation>Ograniczenia</translation>
    </message>
    <message>
        <location line="+99"/>
        <source>&lt;small&gt;Override normal speed limits manually or at scheduled times&lt;/small&gt;</source>
        <translation>&lt;small&gt;Zastępuje zwykłe ograniczenia prędkości ręcznie lub w&#xa0;zaplanowanym czasie&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>&amp;Scheduled times:</source>
        <translation>Zaplanowany cza&amp;s:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>&amp;On days:</source>
        <translation>W&#xa0;d&amp;niach:</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+382"/>
        <source>Every Day</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekdays</source>
        <translation>Dni robocze</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weekends</source>
        <translation>Weekendy</translation>
    </message>
    <message>
        <location line="-238"/>
        <source>Sunday</source>
        <translation>Niedziela</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Monday</source>
        <translation>Poniedziałek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tuesday</source>
        <translation>Wtorek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Wednesday</source>
        <translation>Środa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Thursday</source>
        <translation>Czwartek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Friday</source>
        <translation>Piątek</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saturday</source>
        <translation>Sobota</translation>
    </message>
    <message>
        <location line="+299"/>
        <source>Port is &lt;b&gt;open&lt;/b&gt;</source>
        <translation>Port jest &lt;b&gt;otwarty&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Port is &lt;b&gt;closed&lt;/b&gt;</source>
        <translation>Port jest &lt;b&gt;zamknięty&lt;/b&gt;</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Testing TCP Port…</source>
        <translation>Testowanie portu TCP…</translation>
    </message>
    <message>
        <location line="+154"/>
        <source>Select &quot;Torrent Done Downloading&quot; Script</source>
        <translation>Wybór skryptu „Ukończono pobieranie torrenta”</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="+545"/>
        <source>Incoming Peers</source>
        <translation>Połączenia przychodzące</translation>
    </message>
    <message>
        <location line="+32"/>
        <location filename="../PrefsDialog.cc" line="+207"/>
        <source>Status unknown</source>
        <translation>Nieznany stan</translation>
    </message>
    <message>
        <location line="-20"/>
        <source>&amp;Port for incoming connections:</source>
        <translation>&amp;Port połączeń przychodzących:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Use UPnP or NAT-PMP port &amp;forwarding from my router</source>
        <translation>&amp;Przekierowywanie portów z&#xa0;routera za pomocą UPnP lub NAT-PMP</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="-255"/>
        <source> minute(s)</source>
        <extracomment>Spin box suffix, &quot;Stop seeding if idle for: [ 5 minutes ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform> minuta</numerusform>
            <numerusform> minuty</numerusform>
            <numerusform> minut</numerusform>
        </translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Select &quot;Torrent Done Seeding&quot; Script</source>
        <translation>Wybór skryptu „Ukończono wysyłanie torrenta”</translation>
    </message>
    <message numerus="yes">
        <location line="+19"/>
        <source> minute(s) ago</source>
        <extracomment>Spin box suffix, &quot;Download is inactive if data sharing stopped: [ 5 minutes ago ]&quot; (includes leading space after the number, if needed)</extracomment>
        <translation>
            <numerusform> minuta temu</numerusform>
            <numerusform> minuty temu</numerusform>
            <numerusform> minut temu</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-651"/>
        <source>Automatically add .torrent files &amp;from:</source>
        <translation>&amp;Automatyczne dodawanie plików .torrent z:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Show the Torrent Options &amp;dialog</source>
        <translation>Wyświetlanie &amp;okna opcji torrenta</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>&amp;Start added torrents</source>
        <translation>&amp;Rozpoczynanie dodanych torrentów</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Mo&amp;ve the .torrent file to the trash</source>
        <translation>&amp;Przeniesienie pliku .torrent do kosza</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Download Queue</source>
        <translation>Kolejka pobierania</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Ma&amp;ximum active downloads:</source>
        <translation>Ma&amp;ksymalna liczba aktywnych pobierań:</translation>
    </message>
    <message>
        <location line="+67"/>
        <source>Incomplete</source>
        <translation>Nieukończone</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Seeding</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <location line="+622"/>
        <source>Remote</source>
        <translation>Zdalnie</translation>
    </message>
    <message numerus="yes">
        <location filename="../PrefsDialog.cc" line="+168"/>
        <source>&lt;i&gt;Blocklist contains %Ln rule(s)&lt;/i&gt;</source>
        <translation>
            <numerusform>&lt;i&gt;Lista blokowania zawiera %Ln regułę&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Lista blokowania zawiera %Ln reguły&lt;/i&gt;</numerusform>
            <numerusform>&lt;i&gt;Lista blokowania zawiera %Ln reguł&lt;/i&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-339"/>
        <source>Pick a &amp;random port every time Transmission is started</source>
        <translation>&amp;Losowanie portu po każdym uruchomieniu programu</translation>
    </message>
    <message>
        <location line="-274"/>
        <source>Limits</source>
        <translation>Ograniczenia</translation>
    </message>
    <message>
        <location line="+321"/>
        <source>Maximum peers per &amp;torrent:</source>
        <translation>Maksymalna liczba partnerów na &amp;torrent:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Maximum peers &amp;overall:</source>
        <translation>&amp;Maksymalna liczba partnerów:</translation>
    </message>
    <message>
        <location line="-193"/>
        <source>Blocklist</source>
        <translation>Lista blokowania</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Enable &amp;automatic updates</source>
        <translation>&amp;Automatyczne aktualizowanie</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="-227"/>
        <source>Allow encryption</source>
        <translation>Zezwolenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prefer encryption</source>
        <translation>Preferowanie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Require encryption</source>
        <translation>Wymaganie</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-97"/>
        <source>Privacy</source>
        <translation>Prywatność</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>&amp;to</source>
        <translation>&amp;do</translation>
    </message>
    <message>
        <location line="+847"/>
        <location line="+9"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show Transmission icon in the &amp;notification area</source>
        <translation>Ikona programu w&#xa0;obszarze p&amp;owiadamiania</translation>
    </message>
    <message>
        <location line="-265"/>
        <source>Te&amp;st Port</source>
        <translation>Przete&amp;stuj port</translation>
    </message>
    <message>
        <location line="-101"/>
        <source>Enable &amp;blocklist:</source>
        <translation>&amp;Włączenie listy blokowania:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Update</source>
        <translation>Zakt&amp;ualizuj</translation>
    </message>
    <message>
        <location line="-66"/>
        <source>&amp;Encryption mode:</source>
        <translation>&amp;Tryb:</translation>
    </message>
    <message>
        <location line="+505"/>
        <source>Remote Control</source>
        <translation>Zdalne sterowanie</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Allow &amp;remote access</source>
        <translation>&amp;Włączone</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>HTTP &amp;port:</source>
        <translation>&amp;Port HTTP:</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Only allow these IP a&amp;ddresses:</source>
        <translation>&amp;Zezwolenie tylko podanym adresom IP:</translation>
    </message>
    <message>
        <location line="-1212"/>
        <source>&amp;Upload:</source>
        <translation>&amp;Wysyłanie:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Download:</source>
        <translation>&amp;Pobieranie:</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Alternative Speed Limits</source>
        <translation>Alternatywne ograniczenia</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>U&amp;pload:</source>
        <translation>Wy&amp;syłanie:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Do&amp;wnload:</source>
        <translation>Po&amp;bieranie:</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Reads user clipboard content for torrents</source>
        <translation>Odczytuje zawartość schowka użytkownika w&#xa0;poszukiwaniu torrentów</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Detect new torrents from clipboard</source>
        <translation>Wykrywanie nowych torrentów w&#xa0;schowku</translation>
    </message>
    <message>
        <location line="+148"/>
        <source>Call scrip&amp;t when downloading is completed:</source>
        <translation>Wywołanie &amp;skryptu po ukończeniu pobierania:</translation>
    </message>
    <message>
        <location line="+105"/>
        <source>Call scrip&amp;t when seeding is completed:</source>
        <translation>Wywołanie &amp;skryptu po ukończeniu wysyłania:</translation>
    </message>
    <message>
        <location line="+342"/>
        <source>µTP is a tool for reducing network congestion.</source>
        <translation>µTP umożliwia zmniejszenie przeciążenia sieci</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Enable µ&amp;TP for peer connections</source>
        <translation>Kom_unikacja z&#xa0;partnerami przez µTP</translation>
    </message>
    <message>
        <location line="+61"/>
        <source>Default Public Trackers</source>
        <translation>Domyślne publiczne serwery śledzące</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trackers to use on all public torrents.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;p&gt;To add a new primary URL, add it after a blank line.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Serwery śledzące używane na wszystkich publicznych torrentach.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;p&gt;Zapasowy adres URL należy dodać do następnego wiersza po podstawowym adresie URL.&lt;/p&gt;&lt;p&gt;Nowy podstawowy adres URL należy dodać po pustym wierszu.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Start &amp;minimized in notification area</source>
        <translation>Uruchamianie z&amp;minimalizowanego programu w&#xa0;obszarze powiadamiania</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Notification</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show a notification when torrents are a&amp;dded</source>
        <translation>Po &amp;dodaniu torrenta</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show a notification when torrents &amp;finish</source>
        <translation>Po &amp;ukończeniu torrenta</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Play a &amp;sound when torrents finish</source>
        <translation>&amp;Dźwięk po ukończeniu torrenta</translation>
    </message>
    <message>
        <location line="-281"/>
        <source>Peer Limits</source>
        <translation>Ograniczenia partnerów</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Use PE&amp;X to find more peers</source>
        <translation>Wyszukiwanie partnerów przez PE&amp;X</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>PEX is a tool for exchanging peer lists with the peers you&apos;re connected to.</source>
        <translation>PEX umożliwia wymianę list partnerów z&#xa0;połączonymi partnerami</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;DHT to find more peers</source>
        <translation>Wyszukiwanie partnerów przez &amp;DHT</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>DHT is a tool for finding peers without a tracker.</source>
        <translation>DHT umożliwia wyszukiwanie partnerów bez udziału serwera śledzącego</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Use &amp;Local Peer Discovery to find more peers</source>
        <translation>Wykrywanie partnerów &amp;lokalnych</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>LPD is a tool for finding peers on your local network.</source>
        <translation>LPD umożliwia wyszukiwanie partnerów w&#xa0;sieci lokalnej</translation>
    </message>
    <message>
        <location line="-325"/>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+75"/>
        <source>Select Incomplete Directory</source>
        <translation>Wybór katalogu na nieukończone torrenty</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Select Watch Directory</source>
        <translation>Wybór obserwowanego katalogu</translation>
    </message>
    <message numerus="yes">
        <location line="-101"/>
        <source>&lt;b&gt;Update succeeded!&lt;/b&gt;&lt;p&gt;Blocklist now has %Ln rule(s).&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;b&gt;Zaktualizowano.&lt;/b&gt;&lt;p&gt;Lista blokowania ma teraz %Ln regułę.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Zaktualizowano.&lt;/b&gt;&lt;p&gt;Lista blokowania ma teraz %Ln reguły.&lt;/p&gt;</numerusform>
            <numerusform>&lt;b&gt;Zaktualizowano.&lt;/b&gt;&lt;p&gt;Lista blokowania ma teraz %Ln reguł.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&lt;b&gt;Update Blocklist&lt;/b&gt;&lt;p&gt;Getting new blocklist…&lt;/p&gt;</source>
        <translation>&lt;b&gt;Aktualizacja listy blokowania&lt;/b&gt;&lt;p&gt;Pobieranie nowej listy blokowania…&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+93"/>
        <source>Select Destination</source>
        <translation>Wybór miejsca docelowego</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.ui" line="-387"/>
        <source>Adding</source>
        <translation>Dodawanie</translation>
    </message>
    <message>
        <location line="+147"/>
        <source>Download is i&amp;nactive if data sharing stopped:</source>
        <extracomment>Please keep this phrase as short as possible, it&apos;s currently the longest and influences dialog width</extracomment>
        <translation>Pobieranie jest &amp;nieaktywne, jeśli zatrzymano wysyłanie danych:</translation>
    </message>
    <message>
        <location line="-156"/>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location line="+215"/>
        <source>Append &quot;.&amp;part&quot; to incomplete files&apos; names</source>
        <translation>&amp;Dodawanie „.part” do nazw nieukończonych plików</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Keep &amp;incomplete files in:</source>
        <translation>Przechowywanie nie&amp;ukończonych torrentów w:</translation>
    </message>
    <message>
        <location line="-201"/>
        <source>Save to &amp;Location:</source>
        <translation>&amp;Zapisywanie w:</translation>
    </message>
    <message>
        <location line="+282"/>
        <source>Stop seeding at &amp;ratio:</source>
        <translation>Zatrzymanie po osiągnięciu &amp;udziału:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Stop seedi&amp;ng if idle for:</source>
        <translation>Zatrzymanie po braku &amp;aktywności przez:</translation>
    </message>
    <message>
        <location line="-567"/>
        <source>Transmission Preferences</source>
        <translation>Preferencje</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
    <message>
        <location line="+735"/>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../PrefsDialog.cc" line="+116"/>
        <source>Not supported by remote sessions</source>
        <translation>Nieobsługiwane w&#xa0;zdalnych sesjach</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../Application.cc" line="-313"/>
        <source>Invalid option</source>
        <translation>Nieprawidłowa opcja</translation>
    </message>
    <message>
        <location line="+312"/>
        <source>Start Now</source>
        <translation>Rozpocznij teraz</translation>
    </message>
</context>
<context>
    <name>RelocateDialog</name>
    <message>
        <location filename="../RelocateDialog.cc" line="+65"/>
        <source>Select Location</source>
        <translation>Wybór położenia</translation>
    </message>
    <message>
        <location filename="../RelocateDialog.ui" line="+14"/>
        <source>Set Torrent Location</source>
        <translation>Ustawienie położenia torrenta</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Set Location</source>
        <translation>Ustawienie położenia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>New &amp;location:</source>
        <translation>N&amp;owe położenie:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Move from the current folder</source>
        <translation>P&amp;rzeniesienie z&#xa0;bieżącego katalogu</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Local data is &amp;already there</source>
        <translation>&amp;Nowe położenie zawiera pobrane dane</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../Session.cc" line="+505"/>
        <source>Error Renaming Path</source>
        <translation>Błąd podczas zmieniania nazwy ścieżki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;p&gt;&lt;b&gt;Unable to rename &quot;%1&quot; as &quot;%2&quot;: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please correct the errors and try again.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Nie można zmienić nazwy pliku „%1” na „%2”: %3.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Proszę poprawić błędy i spróbować ponownie.&lt;/p&gt;</translation>
    </message>
    <message>
        <location line="+528"/>
        <source>Error Adding Torrent</source>
        <translation>Błąd podczas dodawania torrenta</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>%1 (copy of %2)</source>
        <translation>%1 (kopia %2)</translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source>Duplicate Torrent(s)</source>
        <translation>
            <numerusform>Podwójny torrent</numerusform>
            <numerusform>Podwójne torrenty</numerusform>
            <numerusform>Podwójne torrenty</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+2"/>
        <source>Unable to add %n duplicate torrent(s)</source>
        <translation>
            <numerusform>Nie można dodać %n podwójnego torrenta</numerusform>
            <numerusform>Nie można dodać %n podwójnych torrentów</numerusform>
            <numerusform>Nie można dodać %n podwójnych torrentów</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SessionDialog</name>
    <message>
        <location filename="../SessionDialog.ui" line="+14"/>
        <source>Change Session</source>
        <translation>Zmiana sesji</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Start &amp;Local Session</source>
        <translation>&amp;Rozpoczęcie lokalnej sesji</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Connect to &amp;Remote Session</source>
        <translation>&amp;Połączenie ze zdalną sesją</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Host:</source>
        <translation>&amp;Komputer:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Port:</source>
        <translation>&amp;Port:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Authentication required</source>
        <translation>&amp;Wymaga uwierzytelnienia</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Username:</source>
        <translation>Nazwa &amp;użytkownika:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Pass&amp;word:</source>
        <translation>&amp;Hasło:</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <location filename="../StatsDialog.ui" line="+14"/>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Current Session</source>
        <translation>Bieżąca sesja</translation>
    </message>
    <message>
        <location line="+12"/>
        <location line="+96"/>
        <source>Uploaded:</source>
        <translation>Wysłano:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Downloaded:</source>
        <translation>Pobrano:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Ratio:</source>
        <translation>Udział:</translation>
    </message>
    <message>
        <location line="-82"/>
        <location line="+96"/>
        <source>Duration:</source>
        <translation>Czas trwania:</translation>
    </message>
    <message>
        <location line="-61"/>
        <source>Total</source>
        <translation>Całkowicie</translation>
    </message>
    <message numerus="yes">
        <location filename="../StatsDialog.cc" line="+63"/>
        <source>Started %Ln time(s)</source>
        <translation>
            <numerusform>Rozpoczęto %Ln raz</numerusform>
            <numerusform>Rozpoczęto %Ln razy</numerusform>
            <numerusform>Rozpoczęto %Ln razy</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Torrent</name>
    <message>
        <location filename="../Torrent.cc" line="+323"/>
        <source>Verifying local data</source>
        <translation>Sprawdzanie pobranych danych</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Seeding</source>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <location line="-18"/>
        <source>Finished</source>
        <translation>Ukończono</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Queued for verification</source>
        <translation>W&#xa0;kolejce do sprawdzenia</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for download</source>
        <translation>W&#xa0;kolejce do pobrania</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Queued for seeding</source>
        <translation>W&#xa0;kolejce do wysyłania</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Tracker gave a warning: %1</source>
        <translation>Serwer śledzący zwrócił ostrzeżenie: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tracker gave an error: %1</source>
        <translation>Serwer śledzący zwrócił błąd: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
</context>
<context>
    <name>TorrentDelegate</name>
    <message>
        <location filename="../TorrentDelegate.cc" line="+174"/>
        <source>Magnetized transfer - retrieving metadata (%1%)</source>
        <extracomment>First part of torrent progress string, %1 is the percentage of torrent metadata downloaded</extracomment>
        <translation>Przesyłanie magnet — pobieranie metadanych (%1%)</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>%1 of %2 (%3%)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is how much we&apos;ll have when done, %3 is a percentage of the two</extracomment>
        <translation>%1 z&#xa0;%2 (%3%)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5 Goal: %6)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio, %6 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1 z&#xa0;%2 (%3%), wysłano %4 (udział: %5, docelowo: %6)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>%1 of %2 (%3%), uploaded %4 (Ratio: %5)</source>
        <extracomment>First part of torrent progress string, %1 is how much we&apos;ve got, %2 is the torrent&apos;s total size, %3 is a percentage of the two, %4 is how much we&apos;ve uploaded, %5 is our upload-to-download ratio</extracomment>
        <translation>%1 z&#xa0;%2 (%3%), wysłano %4 (udział: %5)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>%1, uploaded %2 (Ratio: %3 Goal: %4)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio, %4 is the ratio we want to reach before we stop uploading</extracomment>
        <translation>%1, wysłano %2 (udział: %3, docelowo: %4)</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>%1, uploaded %2 (Ratio: %3)</source>
        <extracomment>First part of torrent progress string, %1 is the torrent&apos;s total size, %2 is how much we&apos;ve uploaded, %3 is our upload-to-download ratio</extracomment>
        <translation>%1, wysłano %2 (udział: %3)</translation>
    </message>
    <message>
        <location line="+15"/>
        <source> - %1 left</source>
        <extracomment>Second (optional) part of torrent progress string, %1 is duration, notice that leading space (before the dash) is included here</extracomment>
        <translation> — pozostało: %1</translation>
    </message>
    <message>
        <location line="+6"/>
        <source> - Remaining time unknown</source>
        <extracomment>Second (optional) part of torrent progress string, notice that leading space (before the dash) is included here</extracomment>
        <translation> — pozostały czas jest nieznany</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Ratio: %1</source>
        <translation>Udział: %1</translation>
    </message>
    <message numerus="yes">
        <location line="+44"/>
        <source>Downloading from %Ln peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Pobieranie od %Ln partnera</numerusform>
            <numerusform>Pobieranie od %Ln partnerów</numerusform>
            <numerusform>Pobieranie od %Ln partnerów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+22"/>
        <source>Seeding to %Ln peer(s)</source>
        <translation>
            <numerusform>Wysyłanie do %Ln partnera</numerusform>
            <numerusform>Wysyłanie do %Ln partnerów</numerusform>
            <numerusform>Wysyłanie do %Ln partnerów</numerusform>
        </translation>
    </message>
    <message>
        <location line="+18"/>
        <source> - </source>
        <translation> — </translation>
    </message>
    <message numerus="yes">
        <location line="-50"/>
        <source>Downloading metadata from %Ln peer(s) (%1% done)</source>
        <translation>
            <numerusform>Pobieranie metadanych od %Ln partnera (ukończono %1%)</numerusform>
            <numerusform>Pobieranie metadanych od %Ln partnerów (ukończono %1%)</numerusform>
            <numerusform>Pobieranie metadanych od %Ln partnerów (ukończono %1%)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+15"/>
        <source>Downloading from %1 of %Ln connected peer(s)</source>
        <extracomment>First part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;</extracomment>
        <translation>
            <numerusform>Pobieranie od %1 z&#xa0;%Ln połączonego partnera</numerusform>
            <numerusform>Pobieranie od %1 z&#xa0;%Ln połączonych partnerów</numerusform>
            <numerusform>Pobieranie od %1 z&#xa0;%Ln połączonych partnerów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+8"/>
        <source> and %Ln web seed(s)</source>
        <extracomment>Second (optional) part of phrase &quot;Downloading from ... of ... connected peer(s) and ... web seed(s)&quot;, notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> i&#xa0;%Ln wysyłającego w&#xa0;sieci</numerusform>
            <numerusform> i&#xa0;%Ln wysyłających w&#xa0;sieci</numerusform>
            <numerusform> i&#xa0;%Ln wysyłających w&#xa0;sieci</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+13"/>
        <source>Seeding to %1 of %Ln connected peer(s)</source>
        <translation>
            <numerusform>Wysyłanie do %1 z&#xa0;%Ln połączonego partnera</numerusform>
            <numerusform>Wysyłanie do %1 z&#xa0;%Ln połączonych partnerów</numerusform>
            <numerusform>Wysyłanie do %1 z&#xa0;%Ln połączonych partnerów</numerusform>
        </translation>
    </message>
    <message>
        <location line="-76"/>
        <source>Verifying local data (%1% tested)</source>
        <translation>Sprawdzanie pobranych danych (sprawdzono %1%)</translation>
    </message>
</context>
<context>
    <name>TrackerDelegate</name>
    <message numerus="yes">
        <location filename="../TrackerDelegate.cc" line="+216"/>
        <source>Got a list of%1 %Ln peer(s)%2 %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>
            <numerusform>Otrzymano listę%1 %Ln partnera%2 %3 temu</numerusform>
            <numerusform>Otrzymano listę%1 %Ln partnerów%2 %3 temu</numerusform>
            <numerusform>Otrzymano listę%1 %Ln partnerów%2 %3 temu</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Peer list request %1timed out%2 %3 ago; will retry</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Żądanie listy partnerów %1przekroczyło czas oczekiwania%2 %3 temu, zostanie ponowione</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Got an error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Otrzymano błąd %1„%2”%3 %4 temu</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>No updates scheduled</source>
        <translation>Brak zaplanowanych aktualizacji</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Asking for more peers in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Wysyłanie zapytania o&#xa0;więcej partnerów za %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for more peers</source>
        <translation>W&#xa0;kolejce do wysłania zapytania o&#xa0;więcej partnerów</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Asking for peer counts now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Wysyłanie zapytania o&#xa0;liczbę partnerów… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message numerus="yes">
        <location line="-40"/>
        <source>Tracker had%1 %Ln seeder(s)%2</source>
        <extracomment>First part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup</extracomment>
        <translation>
            <numerusform>Serwer śledzący miał%1 %Ln wysyłającego%2</numerusform>
            <numerusform>Serwer śledzący miał%1 %Ln wysyłających%2</numerusform>
            <numerusform>Serwer śledzący miał%1 %Ln wysyłających%2</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+6"/>
        <source> and%1 %Ln leecher(s)%2 %3 ago</source>
        <extracomment>Second part of phrase &quot;Tracker had ... seeder(s) and ... leecher(s) ... ago&quot;, %1 and %2 are replaced with HTML markup, %3 is duration; notice that leading space (before &quot;and&quot;) is included here</extracomment>
        <translation>
            <numerusform> i%1 %Ln niewysyłającego%2 %3 temu</numerusform>
            <numerusform> i%1 %Ln niewysyłających%2 %3 temu</numerusform>
            <numerusform> i%1 %Ln niewysyłających%2 %3 temu</numerusform>
        </translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tracker had %1no information%2 on peer counts %3 ago</source>
        <extracomment>%1 and %2 are replaced with HTML markup, %3 is duration</extracomment>
        <translation>Serwer śledzący %1nie miał żadnych informacji%2 o&#xa0;liczbie partnerów %3 temu</translation>
    </message>
    <message>
        <location line="-24"/>
        <source>Got a scrape error %1&quot;%2&quot;%3 %4 ago</source>
        <extracomment>%1 and %3 are replaced with HTML markup, %2 is error message, %4 is duration</extracomment>
        <translation>Otrzymano błąd „scrape” %1„%2”%3 %4 temu</translation>
    </message>
    <message>
        <location line="-17"/>
        <source>Asking for more peers now… &lt;small&gt;%1&lt;/small&gt;</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Wysyłanie zapytania o&#xa0;więcej partnerów… &lt;small&gt;%1&lt;/small&gt;</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Asking for peer counts in %1</source>
        <extracomment>%1 is duration</extracomment>
        <translation>Wysyłanie zapytania o&#xa0;liczbę partnerów za %1</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Queued to ask for peer counts</source>
        <translation>W&#xa0;kolejce do wysłania zapytania o&#xa0;liczbę partnerów</translation>
    </message>
</context>
<context>
    <name>TrackersDialog</name>
    <message>
        <location filename="../TrackersDialog.ui" line="+17"/>
        <source>Edit Trackers</source>
        <translation>Modyfikuj serwery śledzące</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Tracker Announce URLs</source>
        <translation>Adresy URL ogłoszeń serwerów śledzących</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>To add a new primary URL, add it after a blank line.</source>
        <translation>Nowy podstawowy adres URL należy dodać po pustym wierszu.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To add a backup URL, add it on the next line after a primary URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Zapasowy adres URL należy dodać do następnego wiersza po podstawowym adresie URL.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Also see Default Public Trackers in Edit &gt; Preferences &gt; Network</source>
        <translation>Domyślne publiczne serwery śledzące znajdują się w&#xa0;Edycja → Preferencje → Sieć</translation>
    </message>
</context>
</TS>
